package goap

// Owner
type OwnerData struct {
	FullIdType
}

func (actor *OwnerData) GetSelfOrBase() (BaseApChain, bool) {
	return actor.FullIdType.GetSelfOrBase()
}

func (actor *OwnerData) MarshalToMap() map[string]any {
	return actor.FullIdType.MarshalToMapWithName(KEY_W3_SECURITY_OWNER)
}

type PublicKeyData struct {
	Next  BaseApChain
	Id    string
	Owner string
	Key   string
}

func (publickeydata *PublicKeyData) GetSelfOrBase() (BaseApChain, bool) {
	return publickeydata.Next, true
}

func (publickeydata *PublicKeyData) MarshalToMap() map[string]any {
	m := publickeydata.Next.MarshalToMap()
	m[KEY_W3_SECURITY_PUBLICKEY] = []map[string]any{{
		KEY_ID:                       publickeydata.Id,
		KEY_W3_SECURITY_OWNER:        []map[string]any{{KEY_ID: publickeydata.Owner}},
		KEY_W3_SECURITY_PUBLICKEYPEM: []map[string]any{{KEY_VALUE: publickeydata.Key}},
	}}
	return m
}

type PublicKeyPemData struct {
	Next  BaseApChain
	Value ValueValue[bool]
}

func (namedata *PublicKeyPemData) GetSelfOrBase() (BaseApChain, bool) {
	return namedata.Next, true
}

func (namedata *PublicKeyPemData) MarshalToMap() map[string]any {
	return appendWithKey(
		namedata.Next.MarshalToMap(),
		KEY_W3_SECURITY_PUBLICKEYPEM,
		[]map[string]any{namedata.Value.Marshal()},
	)
}
